==> foundation-2.6.1.tgz: package/RewindTen/RewindTen.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const RewindTen = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.941 49.005a1.51 1.51 0 00.603-1.242l-.609-26.821a1.517 1.517 0 00-.85-1.322 1.518 1.518 0 00-1.566.145l-5.861 4.375-.461.345c-6.527-6.266-15.394-10.094-25.133-9.906-19.532.376-35.115 16.574-34.739 36.103.376 19.53 16.572 35.115 36.104 34.739a36.53 36.53 0 002.1-.105s.469-.024 1.008-.271l.019-.01a2.8 2.8 0 00.719-.495c.033-.031.068-.059.099-.092l.019-.017c.014-.015.019-.03.031-.045a2.58 2.58 0 00.658-1.766c0-.027-.008-.052-.009-.079l-.175-9.105h-.008c0-.028.007-.054.007-.082a2.597 2.597 0 00-2.647-2.548v-.003a21.14 21.14 0 01-2.067.152c-11.556.223-21.14-8.997-21.362-20.55-.223-11.554 8.999-21.135 20.555-21.358 4.878-.094 9.383 1.517 12.998 4.251l-.986.738-5.866 4.375a1.517 1.517 0 00-.583 1.46c.092.556.49 1.019 1.031 1.188l25.609 8.177c.463.15.966.063 1.362-.231z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M67.109 59.835l-5.941 6.204 2.384 2.407 3.139-3.322.269 13.963 4.096-.079-.37-19.242zm14.416-.566c-5.51.106-7.867 5.115-7.771 10.077.096 4.962 2.644 9.906 8.154 9.8 5.51-.106 7.866-5.145 7.771-10.107-.096-4.962-2.644-9.876-8.154-9.77zm.313 16.242c-2.741.053-3.832-2.697-3.901-6.245s.917-6.309 3.658-6.362c2.77-.053 3.832 2.668 3.9 6.216.069 3.548-.916 6.338-3.657 6.391z"
  }));
});
RewindTen.displayName = 'RewindTen';
export const RewindTenDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/RewindTen/RewindTen.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var RewindTen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.941 49.005a1.51 1.51 0 00.603-1.242l-.609-26.821a1.517 1.517 0 00-.85-1.322 1.518 1.518 0 00-1.566.145l-5.861 4.375-.461.345c-6.527-6.266-15.394-10.094-25.133-9.906-19.532.376-35.115 16.574-34.739 36.103.376 19.53 16.572 35.115 36.104 34.739a36.53 36.53 0 002.1-.105s.469-.024 1.008-.271l.019-.01a2.8 2.8 0 00.719-.495c.033-.031.068-.059.099-.092l.019-.017c.014-.015.019-.03.031-.045a2.58 2.58 0 00.658-1.766c0-.027-.008-.052-.009-.079l-.175-9.105h-.008c0-.028.007-.054.007-.082a2.597 2.597 0 00-2.647-2.548v-.003a21.14 21.14 0 01-2.067.152c-11.556.223-21.14-8.997-21.362-20.55-.223-11.554 8.999-21.135 20.555-21.358 4.878-.094 9.383 1.517 12.998 4.251l-.986.738-5.866 4.375a1.517 1.517 0 00-.583 1.46c.092.556.49 1.019 1.031 1.188l25.609 8.177c.463.15.966.063 1.362-.231z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M67.109 59.835l-5.941 6.204 2.384 2.407 3.139-3.322.269 13.963 4.096-.079-.37-19.242zm14.416-.566c-5.51.106-7.867 5.115-7.771 10.077.096 4.962 2.644 9.906 8.154 9.8 5.51-.106 7.866-5.145 7.771-10.107-.096-4.962-2.644-9.876-8.154-9.77zm.313 16.242c-2.741.053-3.832-2.697-3.901-6.245s.917-6.309 3.658-6.362c2.77-.053 3.832 2.668 3.9 6.216.069 3.548-.916 6.338-3.657 6.391z"
  }));
});
RewindTen.displayName = 'RewindTen';
export var RewindTenDimensions = {
  height: 100,
  width: 100
};
